<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => '
Dre ziouer, an holl liammoù etrezek skeudennoù (gant un astenn o diskrivañ ar mime/stumm ar skeudenn) hag al liammoù gant ar rumm <code>.mediabox</code> a vez astennet gant ar voest miltimedia.
	
	Posubl eo kefluniañ pep liamm unan hag unan gant rummadoù ouzhpenn : 

-* <code>boxIframe</code> evit goulenn digeriñ al laimm e-barzh ur voest mod iframe ;

-* <code>boxWidth-350px</code> evit spisañ ul ledander a 350px evit ar voest ;

-* <code>boxHeight-90pc</code> evit spisañ un uhelder a 90% evit ar voest.
	
Gant ur panel kefluniadur e c’hallit kemmañ ar penn-dibarzhoù giz ma plij deoc’h, hag ivez neuz ar voest gant ar stummoù kinniget.
	
	Ar plugin-se a ya gant skeledennoù oc’h ober gant an arouez
 <code>#INSERT_HEAD</code>',
	'mediabox_nom' => 'MediaBoest',
	'mediabox_slogan' => 'Boest liesvedia',
];
